==> jc-1.4.0.tar.gz: java/nio/channels/UnresolvedAddressException.h <==
// public class java.nio.channels.UnresolvedAddressException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8b25366e4eb52090 java_nio_channels_UnresolvedAddressException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_UnresolvedAddressException_H_
#define _JC_java_nio_channels_UnresolvedAddressException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_UnresolvedAddressException$sub_refs	_jc_java_nio_channels_UnresolvedAddressException$sub_refs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs	_jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$refs	_jc_java_nio_channels_UnresolvedAddressException$refs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$nonrefs	_jc_java_nio_channels_UnresolvedAddressException$nonrefs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$object	_jc_java_nio_channels_UnresolvedAddressException$object;

typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vmethods	_jc_java_nio_channels_UnresolvedAddressException$vmethods;
typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vtable	_jc_java_nio_channels_UnresolvedAddressException$vtable;
typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vtype	_jc_java_nio_channels_UnresolvedAddressException$vtype;

// Constructors
extern void _jc_java_nio_channels_UnresolvedAddressException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_UnresolvedAddressException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_UnresolvedAddressException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_UnresolvedAddressException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_UnresolvedAddressException$vmethods	java_nio_channels_UnresolvedAddressException;
};

// Vtype
struct _jc_java_nio_channels_UnresolvedAddressException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_UnresolvedAddressException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_UnresolvedAddressException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_UnresolvedAddressException$refs {
    _jc_java_nio_channels_UnresolvedAddressException$sub_refs	java_nio_channels_UnresolvedAddressException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_UnresolvedAddressException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs	java_nio_channels_UnresolvedAddressException;
};

// Object instance structure
struct _jc_java_nio_channels_UnresolvedAddressException$object {
	_jc_java_nio_channels_UnresolvedAddressException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_UnresolvedAddressException$vtype	*vtype;
	_jc_java_nio_channels_UnresolvedAddressException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_UnresolvedAddressException$vtype _jc_java_nio_channels_UnresolvedAddressException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_UnresolvedAddressException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_UnresolvedAddressException$class_object;

#endif	/* _JC_java_nio_channels_UnresolvedAddressException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/UnresolvedAddressException.h <==
// public class java.nio.channels.UnresolvedAddressException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8b25366e4eb52090 java_nio_channels_UnresolvedAddressException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_UnresolvedAddressException_H_
#define _JC_java_nio_channels_UnresolvedAddressException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_UnresolvedAddressException$sub_refs	_jc_java_nio_channels_UnresolvedAddressException$sub_refs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs	_jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$refs	_jc_java_nio_channels_UnresolvedAddressException$refs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$nonrefs	_jc_java_nio_channels_UnresolvedAddressException$nonrefs;
typedef struct _jc_java_nio_channels_UnresolvedAddressException$object	_jc_java_nio_channels_UnresolvedAddressException$object;

typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vmethods	_jc_java_nio_channels_UnresolvedAddressException$vmethods;
typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vtable	_jc_java_nio_channels_UnresolvedAddressException$vtable;
typedef const struct _jc_java_nio_channels_UnresolvedAddressException$vtype	_jc_java_nio_channels_UnresolvedAddressException$vtype;

// Constructors
extern void _jc_java_nio_channels_UnresolvedAddressException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_UnresolvedAddressException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_UnresolvedAddressException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_UnresolvedAddressException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_UnresolvedAddressException$vmethods	java_nio_channels_UnresolvedAddressException;
};

// Vtype
struct _jc_java_nio_channels_UnresolvedAddressException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_UnresolvedAddressException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_UnresolvedAddressException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_UnresolvedAddressException$refs {
    _jc_java_nio_channels_UnresolvedAddressException$sub_refs	java_nio_channels_UnresolvedAddressException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_UnresolvedAddressException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_UnresolvedAddressException$sub_nonrefs	java_nio_channels_UnresolvedAddressException;
};

// Object instance structure
struct _jc_java_nio_channels_UnresolvedAddressException$object {
	_jc_java_nio_channels_UnresolvedAddressException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_UnresolvedAddressException$vtype	*vtype;
	_jc_java_nio_channels_UnresolvedAddressException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_UnresolvedAddressException$vtype _jc_java_nio_channels_UnresolvedAddressException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_UnresolvedAddressException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_UnresolvedAddressException$class_object;

#endif	/* _JC_java_nio_channels_UnresolvedAddressException_H_ */
